@@ -47,7 +47,10 @@ def resolve_tuple_values(*inputs, custom_error = None):
         if len(inputs[0]) != len(inputs):
             # special case for COCO JSON
             if len(inputs) == 3 and len(inputs[0]) == 2 and isinstance(inputs[0][1], dict):
-                return inputs[0][0], inputs[0][1]['bbox'], inputs[0][1]['category_id']
+                try:
+                    return inputs[0][0], inputs[0][1]['bbox'], inputs[0][1]['category_id']
+                except KeyError:
+                    return inputs[0][0], inputs[0][1]['bboxes'], inputs[0][1]['labels']
             if custom_error is not None:
                 raise ValueError(custom_error)
             else:
@@ -71,64 +74,12 @@ def has_nested_dicts(obj):
     return any(isinstance(i, dict) for i in obj.values())
 
 
-def as_scalar(inp):
-    """Converts an input value to a scalar."""
-    if isinstance(inp, (int, float)):
-        return inp
-    if np.isscalar(inp):
-        return inp.item()
-    if isinstance(inp, np.ndarray):
-        return inp.item()
-    from agml.backend.tftorch import torch
-    if isinstance(inp, torch.Tensor):
-        return inp.item()
-    from agml.backend.tftorch import tf
-    if isinstance(inp, tf.Tensor):
-        return inp.numpy()
-    raise TypeError(f"Unsupported variable type {type(inp)}.")
-
-
-def scalar_unpack(inp):
-    """Unpacks a 1-d array into a list of scalars."""
-    return [as_scalar(item) for item in inp]
-
-
-def is_array_like(inp):
-    """Determines if an input is a np.ndarray, torch.Tensor, or tf.Tensor."""
-    if isinstance(inp, np.ndarray):
-        return True
-    from agml.backend.tftorch import torch
-    if isinstance(inp, torch.Tensor):
-        return True
-    from agml.backend.tftorch import tf
-    if isinstance(inp, tf.Tensor):
-        return True
-    return False
-
-
-class seed_context(object):
-    """Creates a context with a custom random seed, then resets it.
-
-    This allows for setting a custom seed (for reproducibility) in a
-    context, then resetting the original state after exiting, to
-    prevent interfering with the program execution.
-    """
-
-    def __init__(self, seed):
-        self._seed = seed
-        self._prev_state = None
-
-    def __enter__(self):
-        self._prev_state = np.random.get_state()
-        np.random.seed(self._seed)
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        np.random.set_state(self._prev_state)
-        self._prev_state = None
-
-    def reset(self):
-        np.random.seed(self._seed)
+def shapes(seq):
+    """Returns the shapes (or lengths) of all of the objects in the sequence."""
+    try:
+        return [getattr(obj, 'shape', len(obj)) for obj in seq]
+    except:
+        raise ValueError(f"One or more of the objects has no shape or length: {seq}.")
 
 
 
